@@ -1,10 +1,17 @@
-def bar_template():
+import os
+
+
+def bar_template():  # Template for load bar
     return '%(label)s  %(bar)s  %(info)s'
 
 
-def get_ext(file):
-    index = file.rfind('.')  # Getting the type of file
-    return file[index:].lower()
+def get_ext(file='', path=''):
+    if path:
+        index = path.rfind('\\')
+        return path[index+1:]
+    else:
+        index = file.rfind('.')  # Getting the type of file
+        return file[index:].lower()
 
 
 def file_types():
@@ -13,3 +20,8 @@ def file_types():
                       'videos': ('.mp4', '.avi', '.wmv', '.mov', '.avchd')},
             'docs': ('.pdf', '.ppt', '.docx', '.txt', '.xls', '.doc')}
 
+
+
+
+
+
